@@ -76,7 +76,7 @@ static const wxCmdLineEntryDesc cmdLineDesc[] =
 	  wxT("connect outputs to these jack ports (separate each channel with commas).\n")
 	      "\t\t\tDefaults to 'alsa_pcm:playback_1,...'" },
 	{ wxCMD_LINE_OPTION, wxT("n"), wxT("jack-name"), wxT("jack name.   default is freqtweak_1")},
-	{ wxCMD_LINE_OPTION, wxT("D"), wxT("tmpdir"), wxT("jack server tmp directory (should match jackd --tmpdir)")},
+	{ wxCMD_LINE_OPTION, wxT("S"), wxT("jack-server"), wxT("jack server name")},
 	{ wxCMD_LINE_OPTION, wxT("p"), wxT("preset"), wxT("load given preset initially")},
 	{ wxCMD_LINE_OPTION, wxT("r"), wxT("rc-dir"), wxT("what directory to use for run-control state. default is ~/.freqtweak")},
 	{ wxCMD_LINE_NONE }
@@ -252,13 +252,13 @@ bool FTapp::OnInit()
 		pcnt = (int) longval;
 	}
 
-	if (parser.Found (wxT("D"), &jackdir)) {
-	       FTioSupport::setDefaultDir ((const char *) jackdir.c_str());
+	if (parser.Found (wxT("S"), &jackdir)) {
+	       FTioSupport::setDefaultServer ((const char *) jackdir.ToAscii());
 	}
 	
 	if (parser.Found (wxT("n"), &jackname)) {
 		// FIXME: needs wchar_t->char conversion
-       	       FTioSupport::setDefaultName (jackname.mb_str ());
+       	       FTioSupport::setDefaultName ((const char *)jackname.ToAscii());
 	}
 
 	parser.Found (wxT("r"), &rcdir);
@@ -355,11 +355,11 @@ bool FTapp::OnInit()
 			// connect initial I/O
 			for (int id=0; id < icnt; ++id)
 			{
-				iosup->connectPathInput(id, inputports[id].mb_str());
+				iosup->connectPathInput(id, (const char *) inputports[id].ToAscii());
 			}
 			for (int id=0; id < ocnt; ++id)
 			{
-				iosup->connectPathOutput(id, outputports[id].mb_str());
+				iosup->connectPathOutput(id, (const char *) outputports[id].ToAscii());
 			}
 
 			// load last settings
