@@ -119,7 +119,7 @@ FTspectragram::FTspectragram(FTmainwin * mwin, wxWindow *parent, wxWindowID id,
 
 	_linePen.SetColour(255,255,255);
 
-	
+	updateSize();
 }
 
 FTspectragram::~FTspectragram()
@@ -200,7 +200,7 @@ void FTspectragram::OnPaint(wxPaintEvent & event)
 }
 
 
-void FTspectragram::OnSize(wxSizeEvent & event)
+void FTspectragram::updateSize()
 {
 	int w,h;
 	GetClientSize(&w, &h);
@@ -224,8 +224,11 @@ void FTspectragram::OnSize(wxSizeEvent & event)
 		//_rasterImage = new wxImage(_width, 1 , _rasterData, true);
 		_rasterImage = new wxImage(_dataLength, 1 , _rasterData, true);
 	}
-	
-	
+}
+
+void FTspectragram::OnSize(wxSizeEvent & event)
+{
+	updateSize();
 	event.Skip();
 }
 
@@ -256,8 +259,8 @@ void FTspectragram::plotNextDataSpectragram (const float *data, int length)
 		sdc.SelectObject(*_imageBuf);
 	else return;
 
-	sdc.SetOptimization(true);
-	dc.SetOptimization(true);
+	//sdc.SetOptimization(true);
+	//dc.SetOptimization(true);
 	//rdc.SetOptimization(true);
 
 	
@@ -276,7 +279,7 @@ void FTspectragram::plotNextDataSpectragram (const float *data, int length)
 	int x1,x2;
 	
 //	if (_width >= length)
-	if (1)
+	if (_width == length)
 	{
 		/*
 		if (_width > length) {
@@ -312,6 +315,101 @@ void FTspectragram::plotNextDataSpectragram (const float *data, int length)
 
 		
 	}
+	else if (_width > length)
+	{
+		double xscale = (double)_width / ((double)length-1);
+      
+		int xadj = (int) (xscale * 0.5);
+
+		double xposf = -xadj;
+		int lasti = 0;
+		coli = 0;
+      
+		for(j = 0; j < length; j++, xposf+=xscale)
+		{
+			i = (int) lrint(xposf);
+	      
+			while (lasti < i) {
+				// fill blanks with last
+
+				binToXRange(lasti, x1, x2, _length, _length);
+				for (int n=x1; n <= x2; ++n) { 
+					_rasterData[3*n] = _colorMap[coli][0];
+					_rasterData[3*n+1] = _colorMap[coli][1];
+					_rasterData[3*n+2] = _colorMap[coli][2];
+				}		      
+				++lasti;
+			}
+	      
+			dbval = powerLogScale(data[j]);
+	      
+			// normalize it from _dataRefMin/Max to 0-numcolors
+			coli = (int) (((dbval - _yMin) / ( _yMax - _yMin)) * _colorCount);
+	      
+			if (coli >= (int)_colorCount) {
+				coli = (int) (_colorCount-1);
+			}
+			else if (coli < 0) {
+				coli = 0;
+			}
+	      
+		}
+		
+		while (lasti < _width) {
+			// fill blanks with last
+			binToXRange(lasti, x1, x2, _length, _length);
+			for (int n=x1; n <= x2; ++n) { 
+				_rasterData[3*n] = _colorMap[coli][0];
+				_rasterData[3*n+1] =  _colorMap[coli][1];
+				_rasterData[3*n+2] =  _colorMap[coli][2];
+			}
+			++lasti;
+		}
+	      
+	}
+	else {
+		j = 0;
+		int nextj;
+		
+		for(i = 0; i < _width; i++)
+		{
+			nextj = (int)((i+1)*xSkipD + 0.5);
+			sum = -100000;
+
+			for (; j < nextj; ++j)
+			{
+				if ((data[j] ) > sum)
+				{
+					sum = (data[j] );
+				}
+			}
+
+			dbval = powerLogScale(sum);
+	    
+			// normalize it from _dataRefMin/Max to 0-numcolors
+			//coli = (int) (((sum - _dataRefMin) / refDiff) * _colorCount);
+
+			coli = (int) (((dbval - _yMin) / ( _yMax - _yMin)) * _colorCount);
+
+			if (coli >= (int) _colorCount) {
+				coli = (int)_colorCount-1;
+			}
+			else if (coli < 0) {
+				coli = 0;
+			}
+	 
+			binToXRange(i, x1, x2, _length, _length);
+			for (int n=x1; n <= x2; ++n) { 
+				_rasterData[3*n] =  _colorMap[coli][0];
+				_rasterData[3*n+1] =  _colorMap[coli][1];
+				_rasterData[3*n+2] =  _colorMap[coli][2];
+			}
+	 
+		}
+
+
+	}
+/*
 	else {
 		// Assume they want average
 		// (_scaleType == DATA_MAX)
@@ -352,12 +450,12 @@ void FTspectragram::plotNextDataSpectragram (const float *data, int length)
 				_rasterData[3*n] = _colorMap[coli][0];
 				_rasterData[3*n + 1] = _colorMap[coli][1];
 				_rasterData[3*n + 2] = _colorMap[coli][2];
-			}
+				}
 
 			
-		}
+			}
 	}
-	
+*/
 	
 	// this is double buffered
 	// move the specbuf down
@@ -369,10 +467,10 @@ void FTspectragram::plotNextDataSpectragram (const float *data, int length)
 	
 	//if (_width > length) {
 		//printf ("undersampled: w=%d  l=%d  sxale=%g\n", _width, length, _xscale);
-		sdc.SetUserScale(_xscale, 1.0);
+	//	sdc.SetUserScale(_xscale, 1.0);
 		//}
 
-	sdc.DrawBitmap (wxBitmap (_rasterImage), 0, 0, false);
+	sdc.DrawBitmap (wxBitmap (*_rasterImage), 0, 0, false);
 	
 	
 	// blit to screen
@@ -394,8 +492,8 @@ void FTspectragram::plotNextDataAmpFreq (const float *data, int length)
 	else
 		return;
 
-	sdc.SetOptimization(true);
-	dc.SetOptimization(true);
+	//sdc.SetOptimization(true);
+	//dc.SetOptimization(true);
 	
 	float dbval, sum;
 	int yval, i, k, j;
@@ -612,7 +710,17 @@ void FTspectragram::initColorTable()
       }
       else if (_colorTableType == COLOR_BVRYW)
       {
-	 _discreteColorCount = 7;
+	      _discreteColorCount = 6;
+	      setDiscreteColor(0, 0, 0, 0); // black
+	      setDiscreteColor(1, 0, 0, 149); // blue
+	      setDiscreteColor(2, 57, 122, 138); // blue-green
+	      setDiscreteColor(3, 92, 165, 79); // green
+	      setDiscreteColor(4, 229, 171, 0); // orange
+	      setDiscreteColor(5, 255, 0, 18); // red
+
+
+	      /*  
+	      _discreteColorCount = 7;
 	 // black
 	 _discreteColors[0][0] = 0;
 	 _discreteColors[0][1] = 0;
@@ -641,7 +749,7 @@ void FTspectragram::initColorTable()
 	 _discreteColors[6][0] = 100;
 	 _discreteColors[6][1] = 160;
 	 _discreteColors[6][2] = 100;
-
+	      */
 	 
 
 	 
@@ -1020,7 +1128,7 @@ void FTspectragram::OnMouseActivity( wxMouseEvent &event)
 
 
 
-void FTspectragram::OnXscaleMenu (wxMenuEvent &event)
+void FTspectragram::OnXscaleMenu (wxCommandEvent &event)
 {
 	//wxMenuItem *item = (wxMenuItem *) event.GetEventObject();
 
